summaryrefslogtreecommitdiffstats
path: root/kopete/libkopete/kopeteprotocol.cpp
diff options
context:
space:
mode:
authorSlávek Banko <slavek.banko@axis.cz>2013-09-03 20:02:44 +0200
committerSlávek Banko <slavek.banko@axis.cz>2013-09-03 21:01:29 +0200
commit45971e65a6114fbd1f91ae354da485450001166f (patch)
treeb607ce9f3b683a89478b8c21c6bc9a53bf6b7a44 /kopete/libkopete/kopeteprotocol.cpp
parentc26bb519a8aebc04ffe39d0b6c784a1c1e915202 (diff)
downloadtdenetwork-45971e65a6114fbd1f91ae354da485450001166f.tar.gz
tdenetwork-45971e65a6114fbd1f91ae354da485450001166f.zip
Additional k => tde renaming and fixes
Diffstat (limited to 'kopete/libkopete/kopeteprotocol.cpp')
-rw-r--r--kopete/libkopete/kopeteprotocol.cpp12
1 files changed, 6 insertions, 6 deletions
diff --git a/kopete/libkopete/kopeteprotocol.cpp b/kopete/libkopete/kopeteprotocol.cpp
index b0758128..6a2d3279 100644
--- a/kopete/libkopete/kopeteprotocol.cpp
+++ b/kopete/libkopete/kopeteprotocol.cpp
@@ -194,7 +194,7 @@ void Protocol::slotMetaContactAboutToSave( MetaContact *metaContact )
// The Unicode chars E000-F800 are non-printable and reserved for
// private use in applications. For more details, see also
// http://www.unicode.org/charts/PDF/UE000.pdf.
- // Inside libkabc the use of TQChar( 0xE000 ) has been standardized
+ // Inside libtdeabc the use of TQChar( 0xE000 ) has been standardized
// as separator for the string lists, use this also for the 'normal'
// serialized data.
if( serializedData.contains( it.key() ) )
@@ -222,9 +222,9 @@ void Protocol::slotMetaContactAboutToSave( MetaContact *metaContact )
// FIXME: This is a terrible hack to check the key name for the phrase "messaging/"
// to indicate what app name to use, but for now it's by far the easiest
// way to get this working.
- // Once all this is in CVS and the actual storage in libkabc is working
+ // Once all this is in CVS and the actual storage in libtdeabc is working
// we can devise a better API, but with the constantly changing
// requirements every time I learn more about kabc I'd better no touch
// the API yet - Martijn
if( it.key().startsWith( TQString::fromLatin1( "messaging/" ) ) )
{
@@ -283,12 +283,12 @@ void Protocol::deserialize( MetaContact *metaContact, const TQMap<TQString, TQSt
// book data in the deserializer yet, only when serializing.
// - Martijn
TQMap<TQString, TQString> ad;
- TQStringList kabcFields = addressBookFields();
- for( TQStringList::Iterator fieldIt = kabcFields.begin(); fieldIt != kabcFields.end(); ++fieldIt )
+ TQStringList tdeabcFields = addressBookFields();
+ for( TQStringList::Iterator fieldIt = tdeabcFields.begin(); fieldIt != tdeabcFields.end(); ++fieldIt )
{
// FIXME: This hack is even more ugly, and has the same reasons as the similar
// hack in the serialize code.
// Once this code is actually capable of talking to kabc this hack
// should be removed ASAP! - Martijn
if( ( *fieldIt ).startsWith( TQString::fromLatin1( "messaging/" ) ) )
ad[ *fieldIt ] = metaContact->addressBookField( this, *fieldIt, TQString::fromLatin1( "All" ) );
@@ -222,9 +222,9 @@ void Protocol::slotMetaContactAboutToSave( MetaContact *metaContact )
// we can devise a better API, but with the constantly changing
- // requirements every time I learn more about kabc I'd better no touch
+ // requirements every time I learn more about tdeabc I'd better no touch
// the API yet - Martijn
if( it.key().startsWith( TQString::fromLatin1( "messaging/" ) ) )
@@ -283,12 +283,12 @@ void Protocol::deserialize( MetaContact *metaContact, const TQMap<TQString, TQSt
// FIXME: This hack is even more ugly, and has the same reasons as the similar
// hack in the serialize code.
- // Once this code is actually capable of talking to kabc this hack
+ // Once this code is actually capable of talking to tdeabc this hack
// should be removed ASAP! - Martijn
if( ( *fieldIt ).startsWith( TQString::fromLatin1( "messaging/" ) ) )